# encoding: utf-8

# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-dns_auto.ycp
# Package:	Configuration of novell-dns
# Summary:	Client for autoinstallation
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: novell-dns_auto.ycp 27914 2006-02-13 14:32:08Z locilka $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of novell-dns settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("novell-dns_auto", [ "Summary", mm ]);
module Yast
  class NovellDnsAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-dns"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellDns auto started")

      Yast.import "NovellDns"
      Yast.include self, "novell-dns/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(NovellDns.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        NovellDns.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        #    import "OesLdap";
        #    OesLdap::autoyast_tool = true;
        @ret = NovellDnsAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = NovellDns.Import(@param)
      # Return actual state
      elsif @func == "Export"
        NovellDns.Read if NovellDns.Settings == nil || NovellDns.Settings == {}
        NovellDns.auto_clone = true
        @ret = NovellDns.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = NovellDns.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = NovellDns.Read
        Progress.set(@progress_orig)
      # Write given settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        NovellDns.write_only = true
        @ret = NovellDns.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        NovellDns.globals_configured = true
        @ret = NovellDns.globals_configured
      elsif @func == "SetModified"
        NovellDns.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellDns auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellDnsAutoClient.new.main
