# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-dns_proposal.ycp
# Package:	Configuration of novell-dns
# Summary:	Proposal function dispatcher.
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: novell-dns_proposal.ycp 27914 2006-02-13 14:32:08Z locilka $
#
# Proposal function dispatcher for novell-dns configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class NovellDnsProposalClient < Client
    def main

      textdomain "novell-dns"

      Yast.import "NovellDns"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellUtils"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellDns proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if NovellUtils.EdirAskUserFlag("dns") # If edir changed, then we need to recompute the defaults.
          @force_reset = true
          Builtins.y2milestone(
            "novell-dns.MakeProposal:force_reset set to true due to ask user flag."
          )
        end

        if @force_reset || !NovellDns.proposal_valid
          NovellDns.proposal_valid = true
          @progress_orig = Progress.set(false)
          NovellDns.Read
          Progress.set(@progress_orig)
        end
        @sum = NovellDns.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("novell-dns", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }

        if !NovellDns.upgradeMode
          if Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            ) == "" &&
              Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == "" ||
              Ops.get_string(NovellDns.Settings, "CONFIG_DNS_LDAP_SERVER", "") == "" ||
              Ops.get_string(NovellDns.Settings, "CONFIG_DNS_LDAP_BASEDN", "") == "" ||
              Ops.get_string(
                NovellDns.Settings,
                "CONFIG_DNS_SERVER_CONTEXT",
                ""
              ) == "" ||
              Ops.get_string(
                NovellDns.Settings,
                "CONFIG_DNS_LOCATOR_CONTEXT",
                ""
              ) == "" ||
              Ops.get_string(
                NovellDns.Settings,
                "CONFIG_DNS_LDAP_USER_CONTEXT",
                ""
              ) == "" ||
              Ops.get_string(
                NovellDns.Settings,
                "CONFIG_DNS_LDAP_USER_PASSWORD",
                ""
              ) == "" ||
              Ops.get_string(NovellDns.Settings, "CONFIG_DNS_GROUP_CONTEXT", "") == ""
            Ops.set(@ret, "errors", true)
          end
        end
        Ops.set(@ret, "errors", false) if NovellDns.xadMode
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("Novell DNS proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "novell-dns--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "novell-dns", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "novell-dns--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "novell-dns", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = NovellDns.ExportSettings
          @seq = Convert.to_symbol(
            WFM.CallFunction("novell-dns", [path(".propose")])
          )
          NovellDns.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @isSelected = NovellPatterns.IsPatternInstalled("novell-dns")
        Builtins.y2milestone(
          "Proposal:IsSelectionInstalled:novell-dns: %1",
          @isSelected
        )
        if @isSelected == true
          @ret = {
            # Rich text title for Novell DNS Services in proposals
            "rich_text_title" => _(
              "OES DNS Services"
            ),
            # Menu title for Novell DNS Services in proposals
            "menu_title"      => _(
              "OES &DNS Services"
            ),
            "id"              => "novell-dns"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        NovellDns.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellDns proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellDnsProposalClient.new.main
