# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-dns/dialogs.ycp
# Package:	Configuration of novell-dns
# Summary:	Dialogs definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: dialogs.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellDnsDialogsInclude
    def initialize_novell_dns_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-dns"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "NovellDns"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "IP"
      Yast.import "Address"

      Yast.include include_target, "novell-dns/complex.rb"
      Yast.include include_target, "novell-dns/helps.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      useXad = false

      if NovellDns.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          useXad = true
        end # if this value is set at all, then it is the eDir admin (in spite of xad name)
      end
      Builtins.y2milestone(
        "NovellDns.PromptIfNeededForEdirAdminPassword:use xad:%1",
        useXad
      )

      if useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end
      Builtins.y2milestone(
        "NovellDns.PromptIfNeededForEdirAdminPassword:useXad %1",
        useXad
      )
      useXad
    end

    # Novelldns 1a dialog
    # @return dialog result
    def NovelldnsDialog_1a
      if NovellDns.upgradeMode
        Popup.Message(NovellUtils.noConfigMessage)
        Builtins.y2milestone(
          "NovellDns.NovellDnsDialog:skipping GUI since we are in upgrade mode."
        )
        return :skip
      end

      if NovellDns.xadMode
        Popup.Message(
          _(
            "When installing DSFW, DNS values are set in the eDirectory/DSFW install."
          )
        )
        Builtins.y2milestone(
          "NovellDns.NovelldnsDialog:returning since we are in XAD mode."
        )
        return :skip
      end

      # Novell DNS Services configure2 dialog caption
      caption = _("OES DNS Configuration")

      ldap_server = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_LDAP_SERVER",
        ""
      )
      if ldap_server == nil || !NovellLDAP.AddressExists(ldap_server, nil)
        ldap_server = ""
      end

      server_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDns.Settings, "CONFIG_DNS_SERVER_CONTEXT", "")
      )
      use_secure_port = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_USE_SECURE_PORT",
        "yes"
      )
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      server_list_widget = NovellLDAPUI.ServerListWidget(
        server_list,
        _("Directory server address"),
        ldap_server,
        true,
        :combo
      )
      ldap_widget = Ops.get_term(server_list_widget, "term") { VBox(:Empty) }

      contents = HVSquash(
        VBox(
          ldap_widget,
          VSpacing(1.0),
          TextEntry(
            Id(:server_context),
            _("Local NCP Server Context (e.g. ou=servers,o=microfocus):"),
            server_context
          ),
          VSpacing(1.0),
          Left(CheckBox(Id(:use_secure_port), _("Use Secure LDAP Port")))
        )
      )

      helps = Ops.add(
        Ops.add(
          Ops.get_string(@HELPS, "configure_dns", ""),
          Ops.get_string(server_list_widget, "helps", "")
        ),
        Ops.get_string(@HELPS, "configure_dns_0", "")
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      if use_secure_port != "no"
        UI.ChangeWidget(Id(:use_secure_port), :Value, true)
      else
        UI.ChangeWidget(Id(:use_secure_port), :Value, false)
      end

      PromptIfNeededForEdirAdminPassword()

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          ldap_server = Convert.to_string(
            UI.QueryWidget(Id(:server_select), :Value)
          )
          Ops.set(NovellDns.Settings, "CONFIG_DNS_LDAP_SERVER", ldap_server)

          server_context = Convert.to_string(
            UI.QueryWidget(Id(:server_context), :Value)
          )
          next if !NovellValidators.ValidateContext(server_context)

          Ops.set(
            NovellDns.Settings,
            "CONFIG_DNS_SERVER_CONTEXT",
            NovellUtils.Nds2Ldap(server_context)
          )

          if Convert.to_boolean(UI.QueryWidget(Id(:use_secure_port), :Value))
            Ops.set(NovellDns.Settings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
          else
            Ops.set(NovellDns.Settings, "CONFIG_DNS_USE_SECURE_PORT", "no")
          end

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # Novelldns 1a_2 dialog
    # @return dialog result
    def NovelldnsDialog_1a_2
      # Novell DNS Services configure 1a_2 dialog caption
      caption = _("OES DNS Configuration")

      storeInOCS = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
        "yes"
      )
      ldap_user = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDns.Settings, "CONFIG_DNS_LDAP_USER_CONTEXT", "")
      )
      ldap_user_password = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_LDAP_USER_PASSWORD",
        ""
      )

      commonProxyName = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_COMMON_PROXY",
        ""
      )
      commonProxyPassword = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_COMMON_PROXY_PASSWORD",
        ""
      )

      ndsTreeType = NovellDns.GetTreeType

      contents = HVSquash(
        VBox(
          MultiLineEdit(
            Id(:ldap_user),
            _("Proxy User for DNS Management"),
            ldap_user
          ),
          VSpacing(1.0),
          HBox(
            Frame(
              _("Credential Storage Location:"),
              MarginBox(
                1.5,
                0.2,
                RadioButtonGroup(
                  Id(:rb),
                  VBox(
                    Left(RadioButton(Id(0), "OCS")),
                    Left(RadioButton(Id(1), _("Local file based format")))
                  )
                )
              )
            )
          )
        )
      )

      helps = Ops.get_string(@HELPS, "configure_dns_m", "")
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      if storeInOCS == "yes"
        UI.ChangeWidget(Id(:rb), :CurrentButton, 0)
      else
        UI.ChangeWidget(Id(:rb), :CurrentButton, 1)
      end

      UI.ChangeWidget(Id(:ldap_user), :Enabled, false)

      full_admin_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      admin_pwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      if NovellDns.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        Builtins.y2milestone(
          "NovellDns:XAD_TREE_ADMIN_CONTEXT:%1",
          xad_tree_admin_context
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          full_admin_context = NovellUtils.Nds2Ldap(xad_tree_admin_context)
          admin_pwd = Ops.get_string(
            NovellLDAP.Settings,
            "XAD_TREE_ADMIN_PASSWORD",
            ""
          )
        end
      end

      if NovellUtils.Nds2Ldap(ldap_user) == full_admin_context &&
          ldap_user_password == ""
        ldap_user_password = admin_pwd
      end

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          # Save the data in oescredstore
          if Convert.to_integer(UI.QueryWidget(Id(:rb), :CurrentButton)) == 0
            Ops.set(
              NovellDns.Settings,
              "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
              "yes"
            )
          else
            Ops.set(
              NovellDns.Settings,
              "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
              "no"
            )
          end

          next if !NovellValidators.ValidatePassword(ldap_user_password)

          if !NovellValidators.ValidateFDN(ldap_user, false)
            name = ldap_user
            name = NovellUtils.Strip(name, " ")
            if name == nil || name == "" || name == " "
              Popup.Error(_("A valid LDAP user must be entered."))
            end
            next
          end

          Builtins.y2milestone(
            "NovellDns:proxy user validation: treeType %1",
            ndsTreeType
          )
          if ndsTreeType != "new" && NovellDns.UserExists(ldap_user)
            doContinue = NovellDns.ValidateCreds(ldap_user, ldap_user_password)
            next if doContinue
          end

          Ops.set(NovellDns.Settings, "CONFIG_DNS_LDAP_USER_CONTEXT", ldap_user)
          Ops.set(
            NovellDns.Settings,
            "CONFIG_DNS_LDAP_USER_PASSWORD",
            ldap_user_password
          )

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # Novelldns 1b dialog
    # @return dialog result
    def NovelldnsDialog_1b
      # Novell DNS Services configure2 dialog caption
      caption = _("OES DNS Configuration")

      ldap_server = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_LDAP_SERVER",
        ""
      )
      if ldap_server == nil || !NovellLDAP.AddressExists(ldap_server, nil)
        ldap_server = ""
      end

      baseDN = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDns.Settings, "CONFIG_DNS_LDAP_BASEDN", "")
      )
      locator_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDns.Settings, "CONFIG_DNS_LOCATOR_CONTEXT", "")
      )
      group_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDns.Settings, "CONFIG_DNS_GROUP_CONTEXT", "")
      )
      existing_address = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_EXISTING_DNS_IP",
        ""
      )

      baseDN = "" if baseDN == nil

      commonProxyName = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_COMMON_PROXY",
        ""
      )
      commonProxyPassword = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_COMMON_PROXY_PASSWORD",
        ""
      )

      ndsTreeType = NovellDns.GetTreeType

      contents = HVSquash(
        VBox(
          Left(
            Frame(
              _("Common DNS Configuration Object and User Contexts"),
              MarginBox(
                1.5,
                0.2,
                VBox(
                  Left(
                    CheckBox(
                      Id(:get_object),
                      Opt(:notify),
                      _("Get context information from existing DNS server")
                    )
                  ),
                  HBox(
                    MinWidth(
                      45,
                      TextEntry(
                        Id(:existing_ip),
                        _("Existing OES DNS server address:"),
                        existing_address
                      )
                    ),
                    VBox(
                      Label(""),
                      Right(PushButton(Id(:rtvBttn), _("&Retrieve")))
                    )
                  ),
                  TextEntry(
                    Id(:locator_context),
                    _(
                      "OES DNS Services Locator Object Context (e.g. ou=dns,o=microfocus):"
                    ),
                    locator_context
                  ),
                  TextEntry(
                    Id(:baseDN),
                    _(
                      "OES DNS Services Root Server Info Context (e.g. ou=dns,o=microfocus):"
                    ),
                    baseDN
                  ),
                  TextEntry(
                    Id(:group_context),
                    _(
                      "OES DNS Services Group Object Context (e.g. ou=dns,o=microfocus):"
                    ),
                    group_context
                  )
                )
              )
            )
          )
        )
      )

      helps = Ops.add(
        Ops.get_string(@HELPS, "configure_dns", ""),
        Ops.get_string(@HELPS, "configure_dns_1", "")
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      if ndsTreeType == "new"
        UI.ChangeWidget(Id(:get_object), :Value, false)
        UI.ChangeWidget(Id(:get_object), :Enabled, false)
        UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      else
        UI.ChangeWidget(Id(:get_object), :Enabled, true)
        UI.ChangeWidget(Id(:get_object), :Value, false)
        UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      end

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          baseDN = Convert.to_string(UI.QueryWidget(Id(:baseDN), :Value))
          next if !NovellValidators.ValidateContext(baseDN)

          Ops.set(
            NovellDns.Settings,
            "CONFIG_DNS_LDAP_BASEDN",
            NovellUtils.Nds2Ldap(baseDN)
          )

          locator_context = Convert.to_string(
            UI.QueryWidget(Id(:locator_context), :Value)
          )
          next if !NovellValidators.ValidateContext(locator_context)

          Ops.set(
            NovellDns.Settings,
            "CONFIG_DNS_LOCATOR_CONTEXT",
            NovellUtils.Nds2Ldap(locator_context)
          )

          group_context = Convert.to_string(
            UI.QueryWidget(Id(:group_context), :Value)
          )
          next if !NovellValidators.ValidateContext(group_context)

          Ops.set(
            NovellDns.Settings,
            "CONFIG_DNS_GROUP_CONTEXT",
            NovellUtils.Nds2Ldap(group_context)
          )

          break
        elsif ret == :get_object
          if Convert.to_boolean(UI.QueryWidget(Id(:get_object), :Value))
            UI.ChangeWidget(Id(:existing_ip), :Enabled, true)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, true)
          else
            UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
          end
          next
        elsif ret == :rtvBttn
          # First validate the IP address
          ip = Convert.to_string(UI.QueryWidget(Id(:existing_ip), :Value))
          if !Address.Check4(ip)
            if ip != ""
              Popup.Error(Address.Valid4)
            else
              Popup.Error(
                _(
                  "A valid IP address / hostname of an existing DNS server must be entered."
                )
              )
            end
            next
          end
          if !NovellUtils.Ping_IP(ip)
            erMsg = Builtins.sformat(
              _(
                "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
              ),
              ip
            )

            next if Popup.ContinueCancel(erMsg) == false
          end


          # Now, try to get the context information.
          contextInfo = NovellDns.GetContextInfo(ip)
          if contextInfo == nil
            UI.ChangeWidget(Id(:get_object), :Value, false)
            UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
            Popup.Message(
              _(
                "The locator, root server, and group contexts could not be obtained automatically.\nTry another IP address / hostname or enter the object contexts manually."
              )
            )
          else
            UI.ChangeWidget(
              Id(:locator_context),
              :Value,
              Ops.get(contextInfo, 0, "")
            )
            UI.ChangeWidget(
              Id(:group_context),
              :Value,
              Ops.get(contextInfo, 1, "")
            )
            UI.ChangeWidget(Id(:baseDN), :Value, Ops.get(contextInfo, 2, ""))
          end
          next
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # Novelldns2 dialog
    # @return dialog result
    def Novelldns2Dialog
      caption = _("OES DNS Server Object Configuration")

      if NovellDns.xadMode
        Builtins.y2milestone(
          "NovellDns.Novelldns2Dialog:returning since we are in XAD mode."
        )
        return :next
      end

      host_name = Ops.get_string(NovellDns.Settings, "CONFIG_DNS_HOST_NAME", "")
      host_name = "" if host_name == nil

      domain_name = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_DOMAIN_NAME",
        ""
      )
      domain_name = "" if domain_name == nil


      create_object = Ops.get_string(
        NovellDns.Settings,
        "CONFIG_DNS_CREATE_SERVER_OBJECT",
        "no"
      )
      createObject = false
      create_object = "no" if create_object == nil

      createObject = true if Builtins.tolower(create_object) == "yes"

      contents = HVSquash(
        VBox(
          Left(
            CheckBox(
              Id(:create_object),
              Opt(:notify),
              _("Create DNS Server Object")
            )
          ),
          TextEntry(
            Id(:host_name),
            _("Host Name (e.g. myhostname):"),
            host_name
          ),
          TextEntry(
            Id(:domain_name),
            _("Domain Name for DNS Server (e.g. provo.novell.com):"),
            domain_name
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "configure_dns_2", ""),
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      if createObject
        UI.ChangeWidget(Id(:create_object), :Value, true)
        UI.ChangeWidget(Id(:host_name), :Enabled, true)
        UI.ChangeWidget(Id(:domain_name), :Enabled, true)
      else
        UI.ChangeWidget(Id(:create_object), :Value, false)
        UI.ChangeWidget(Id(:host_name), :Enabled, false)
        UI.ChangeWidget(Id(:domain_name), :Enabled, false)
        UI.ChangeWidget(Id(:host_name), :Value, "")
        UI.ChangeWidget(Id(:domain_name), :Value, "")
      end

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          if Convert.to_boolean(UI.QueryWidget(Id(:create_object), :Value))
            hostName = Convert.to_string(UI.QueryWidget(Id(:host_name), :Value))
            if hostName == nil || hostName == ""
              Popup.Error(_("A valid host name must be entered."))
              next
            end

            domainName = Convert.to_string(
              UI.QueryWidget(Id(:domain_name), :Value)
            )
            if domainName == nil || domainName == ""
              Popup.Error(_("A valid domain name must be entered."))
              next
            end
            Ops.set(
              NovellDns.Settings,
              "CONFIG_DNS_CREATE_SERVER_OBJECT",
              "yes"
            )
            Ops.set(NovellDns.Settings, "CONFIG_DNS_HOST_NAME", hostName)
            Ops.set(NovellDns.Settings, "CONFIG_DNS_DOMAIN_NAME", domainName)
          else
            Ops.set(NovellDns.Settings, "CONFIG_DNS_HOST_NAME", "")
            Ops.set(NovellDns.Settings, "CONFIG_DNS_DOMAIN_NAME", "")
            Ops.set(NovellDns.Settings, "CONFIG_DNS_CREATE_SERVER_OBJECT", "no")
          end
          break
        elsif ret == :create_object
          if Convert.to_boolean(UI.QueryWidget(Id(:create_object), :Value))
            UI.ChangeWidget(Id(:host_name), :Enabled, true)
            UI.ChangeWidget(Id(:domain_name), :Enabled, true)
            UI.ChangeWidget(Id(:host_name), :Value, host_name)
            UI.ChangeWidget(Id(:domain_name), :Value, domain_name)
          else
            UI.ChangeWidget(Id(:host_name), :Value, "")
            UI.ChangeWidget(Id(:domain_name), :Value, "")
            UI.ChangeWidget(Id(:host_name), :Enabled, false)
            UI.ChangeWidget(Id(:domain_name), :Enabled, false)
          end
          next
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
