# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006-2007 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-dns/helps.ycp
# Package:	Configuration of novell-dns
# Summary:	Help texts of all the dialogs
# Authors:	Mark Clark <mclark@novell.com>, Bindu Nayar <nbindu.BLR.BANGALORE@novell.com>
#
# $Id: helps.ycp 27914 2007-02-27 14:32:08Z locilka $
module Yast
  module NovellDnsHelpsInclude
    def initialize_novell_dns_helps(include_target)
      textdomain "novell-dns"

      # Modify the help text here.
      #
      @HELPS = {
        # Read dialog help 1/2
        "read"            => _(
          "<p><b><big>Initializing OES-DNS Configuration</big></b><br>\nPlease wait...<br></p>\n"
        ) +
          # Read dialog help 2/2
          _(
            "<p><b><big>Aborting Initialization</big></b><br>\nSafely abort the configuration utility by clicking <b>Abort</b> now.</p>\n"
          ),
        # Write dialog help 1/2
        "write"           => _(
          "<p><b><big>Saving OES DNS Configuration</big></b><br>\nPlease wait...<br></p>\n"
        ) +
          # Write dialog help 2/2
          _(
            "<p><b><big>Aborting the Save</big></b><br>\n" +
              "Abort the save procedure by clicking <b>Abort</b>.\n" +
              "An additional dialog indicates whether it is safe to do so.\n" +
              "</p>\n"
          ),
        # Summary dialog help 1/3
        "summary"         => _(
          "<p><b><big>OES DNS Configuration</big></b><br>\nConfigure OES DNS here.<br></p>\n"
        ) +
          # Summary dialog help 2/3
          _(
            "<p><b><big>Adding a OES DNS Server</big></b><br>\n" +
              "Choose a OES DNS server from the list of detected OES DNS servers.\n" +
              "If your OES DNS server was not detected, select <b>Other (not detected)</b>,\n" +
              "then click <b>Configure</b>.</p>\n"
          ) +
          # Summary dialog help 3/3
          _(
            "<p><b><big>Editing or Deleting</big></b><br>\nClick <b>Edit</b> to open an additional configuration dialog where you can specify new settings for the OES DNS server.</p>\n"
          ),
        # Overview dialog help 1/3
        "overview"        => _(
          "<p><b><big>OES DNS Configuration Overview</big></b><br>\nUse this dialog to obtain a list of installed OES DNS servers and edit their configurations.</p>\n"
        ) +
          # Overview dialog help 2/3
          _(
            "<p><b><big>Adding a OES DNS Server</big></b><br>\nClick <b>Add</b> to configure a OES DNS server.</p>\n"
          ) +
          # Overview dialog help 3/3
          _(
            "<p><b><big>Editing or Deleting</big></b><br>\n" +
              "Select a OES DNS server to change or remove,\n" +
              "then click <b>Edit</b> or <b>Delete</b>.</p>\n"
          ),
        # DNS Services Configure help 1/1
        "configure_dns"   => _(
          "<p><b><big>OES DNS Services Configuration</big></b><br>\nUse this dialog to specify options for configuring a DNS server that is integrated with eDirectory on this server.</p>\n"
        ),
        # DNS Services Configure help 1/2
        "configure_dns_0" => _(
          "<p><b><big>Local NCP Server Context</big></b><br>\nSpecify a context for the local NCP Server object.<br>For example: ou=servers,o=microfocus</p>\n"
        ) +
          # DNS Services Configure help 2/2
          _(
            "<p><b><big>Use Secure LDAP Port</big></b><br>\nThis option is selected by default to ensure that the data transferred by this service is secure and private. If you deselect this option, the transferred data is in clear text format.</p>\n"
          ),
        # DNS Services Configure help 1/3
        "configure_dns_m" => _(
          "<p><b><big>Proxy User for DNS Management</big></b><br>\n" +
            "This is the Common Proxy user that was created during eDirectory configuration for managing DNS service.</p>\n" +
            "<p>This user is used to authenticate to eDirectory to access information for DNS during runtime. The user must have eDirectory read, write, and browse rights under the specified context.</p>\n" +
            "<p>During eDirectory configuration, if you have selected the 'Use Common Proxy User as default for OES Products' check box, then the proxy user fields is populated with common proxy user name.</p>\n"
        ) +
          # DNS Services Configure help 2/2
          _(
            "<p><b><big>Credential Storage Location</big></b><br>\nSpecify where the proxy user's credentials are to be stored. It is recommended to use OCS.</p>\n"
          ),
        # DNS Services Configure help 1/4
        "configure_dns_1" => _(
          "<p><b><big>Get Context and Proxy User Information from Existing DNS Server</big></b><br>\n" +
            "If you are configuring DNS in an existing tree where DNS is already configured and you want to use the existing Locator, Root Server Info, Group and Proxy User contexts, you can select the 'Get context information from existing DNS server' check box and provide the IP / hostname of an NCP server hosting the existing DNS server and click 'Retrieve'. This will fetch the contexts of the Locator, Root Server Info, Group and Proxy User contexts. Make sure the NCP server hosting the existing DNS server is running before hitting 'Retrieve'.</p>\n" +
            "<p>If you do not wish to use existing contexts, you can provide those manually.</p>\n"
        ) +
          # DNS Services Configure help 2/4
          _(
            "<p><b><big>OES DNS Services Locator Object Context</big></b><br>\n" +
              "Specify the context for the DNS Locator object.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>The Locator object contains global defaults, DHCP options, and a list of all DNS and DHCP servers, subnets, and zones in the tree.</p>\n"
          ) +
          # DNS Services Configure help 3/4
          _(
            "<p><b><big>OES DNS Services Root Server Info Context</big></b><br>\n" +
              "Specify the context for the DNS Services root server.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>The RootSrvrInfo Zone is an eDirectory container object that contains resource records for the DNS root servers</p>\n"
          ) +
          # DNS Services Configure help 4/4
          _(
            "<p><b><big>OES DNS Services Group Object Context</big></b><br>\n" +
              "Specify the context for the DNS Group object.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>This object is used to grant DNS servers the necessary rights to other data within the eDirectory tree.</p>\n"
          ),
        # DNS Services Configure help 1/3
        "configure_dns_2" => _(
          "<p><b><big>Create DNS Server Object</big></b><br>\nCreate the DNS Server object in the eDirectory tree associated with the NCP Server.</p>\n"
        ) +
          # DNS Services Configure help 2/3
          _(
            "<p><b><big>Host Name</big></b><br>\nType the unique hostname for the DNS Server object.</p>\n"
          ) +
          # DNS Services Configure help 3/3
          _(
            "<p><b><big>Domain Name for DNS Server</big></b><br>\nType the domain name for the Server object.</p>\n"
          )
      } 

      # EOF
    end
  end
end
